DependencyBiomarkerPlot <- function(Achilles.file,Biomarker.file,ListOfGenes){
  
  library(ggplot2)
  
  Achilles <- read.table(Achilles.file, header=TRUE, sep=',', row.names=1,check.names=FALSE)
  
  Biomarker <- read.table(Biomarker.file, header=TRUE, sep=',', row.names=1)
  
  
  pdf(paste("DependencyBiomarkerPlots_",paste(ListOfGenes,sep="",collapse="_"),".pdf",sep=""), onefile = TRUE)
  listOfPlots <- list()
  #for each gene, make a df containing the dependency and mutation status, cell lines as row names
  for(i in 1:length(ListOfGenes)){
    gene <- ListOfGenes[i]
    print(paste("Gene: ",gene,sep=""))
    geneMutationStatus <- Biomarker[,which(colnames(Biomarker) == gene),drop=FALSE]
    if(length(geneMutationStatus) == 0){
      print(paste("No Mutation Data for Gene ",gene,sep=""))
      next
    }
    print("Obtained Gene Mutation Status")
    geneDepData <- Achilles[,which(colnames(Achilles) == gene),drop=FALSE]
    if(length(geneDepData) == 0){
      print(paste("No Dependency Data for Gene ",gene,sep=""))
      next
    }
    geneDF <- merge(geneDepData,geneMutationStatus,by="row.names")
    row.names(geneDF) <- geneDF[,c(1)]
    geneDF <- geneDF[,-c(1)]
    colnames(geneDF) <- c("GeneDependencyScore","Biomarker")
    geneDF <- geneDF[complete.cases(geneDF),]
    dbplot <- ggplot(geneDF, aes(x = GeneDependencyScore, fill = factor(Biomarker))) +
      geom_dotplot(method="histodot",binpositions="all",stackgroups=TRUE) + scale_y_continuous(name = "", breaks = NULL) + ggtitle(paste("Gene Dependency Score and Mutation Status:\n",gene,sep="")) + theme(plot.title = element_text(face="bold")) + xlab("Gene Dependency Score") + scale_fill_discrete(name="Mutation Status",breaks=c(0,1),labels=c("Mutation","No Mutation"))
    listOfPlots[[i]] <- dbplot
  }  
  
  lapply(listOfPlots,print)
  dev.off()
  
}